# -*- coding: utf-8 -*-
"""
@author:XuMing(xuming624@qq.com)
@description: 
"""
__version__ = '1.2.0'

from parrots.asr import SpeechRecognition
from parrots.pinyin2hanzi import Pinyin2Hanzi
from parrots.tts import TextToSpeech
from parrots.log import logger, set_log_level, add_file_logger, LOG_LEVEL